==> gfarm2fs_1.2.0.1.orig.tar.gz: gfarm2fs-1.2.0.1/gfarm2fs_msg_enums.h <==
#define GFARM_MSG_2000001	2000001
#define GFARM_MSG_2000002	2000002
#define GFARM_MSG_2000003	2000003
#define GFARM_MSG_2000004	2000004
#define GFARM_MSG_2000005	2000005
#define GFARM_MSG_2000006	2000006
#define GFARM_MSG_2000007	2000007
#define GFARM_MSG_2000008	2000008
#define GFARM_MSG_2000009	2000009
#define GFARM_MSG_2000010	2000010
#define GFARM_MSG_2000011	2000011
#define GFARM_MSG_2000012	2000012
#define GFARM_MSG_2000013	2000013
#define GFARM_MSG_2000014	2000014
#define GFARM_MSG_2000015	2000015
#define GFARM_MSG_2000016	2000016
#define GFARM_MSG_2000017	2000017
#define GFARM_MSG_2000018	2000018
#define GFARM_MSG_2000019	2000019
#define GFARM_MSG_2000020	2000020
#define GFARM_MSG_2000021	2000021
#define GFARM_MSG_2000022	2000022
#define GFARM_MSG_2000023	2000023
#define GFARM_MSG_2000024	2000024
#define GFARM_MSG_2000025	2000025
#define GFARM_MSG_2000026	2000026
#define GFARM_MSG_2000027	2000027
#define GFARM_MSG_2000028	2000028
#define GFARM_MSG_2000029	2000029
#define GFARM_MSG_2000030	2000030
#define GFARM_MSG_2000031	2000031
#define GFARM_MSG_2000032	2000032
#define GFARM_MSG_2000033	2000033
#define GFARM_MSG_2000034	2000034
#define GFARM_MSG_2000035	2000035
#define GFARM_MSG_2000036	2000036
#define GFARM_MSG_2000037	2000037
#define GFARM_MSG_2000038	2000038
#define GFARM_MSG_2000039	2000039
#define GFARM_MSG_2000040	2000040
#define GFARM_MSG_2000041	2000041
#define GFARM_MSG_2000042	2000042
#define GFARM_MSG_2000043	2000043
#define GFARM_MSG_2000044	2000044
#define GFARM_MSG_2000045	2000045

==> gfarm2fs_1.2.1.orig.tar.gz: gfarm2fs-1.2.1/gfarm2fs_msg_enums.h <==
#define GFARM_MSG_2000001	2000001
#define GFARM_MSG_2000002	2000002
#define GFARM_MSG_2000003	2000003
#define GFARM_MSG_2000004	2000004
#define GFARM_MSG_2000005	2000005
#define GFARM_MSG_2000006	2000006
#define GFARM_MSG_2000007	2000007
#define GFARM_MSG_2000008	2000008
#define GFARM_MSG_2000009	2000009
#define GFARM_MSG_2000010	2000010
#define GFARM_MSG_2000011	2000011
#define GFARM_MSG_2000012	2000012
#define GFARM_MSG_2000013	2000013
#define GFARM_MSG_2000014	2000014
#define GFARM_MSG_2000015	2000015
#define GFARM_MSG_2000016	2000016
#define GFARM_MSG_2000017	2000017
#define GFARM_MSG_2000018	2000018
#define GFARM_MSG_2000019	2000019
#define GFARM_MSG_2000020	2000020
#define GFARM_MSG_2000021	2000021
#define GFARM_MSG_2000022	2000022
#define GFARM_MSG_2000023	2000023
#define GFARM_MSG_2000024	2000024
#define GFARM_MSG_2000025	2000025
#define GFARM_MSG_2000026	2000026
#define GFARM_MSG_2000027	2000027
#define GFARM_MSG_2000028	2000028
#define GFARM_MSG_2000029	2000029
#define GFARM_MSG_2000030	2000030
#define GFARM_MSG_2000031	2000031
#define GFARM_MSG_2000032	2000032
#define GFARM_MSG_2000033	2000033
#define GFARM_MSG_2000034	2000034
#define GFARM_MSG_2000035	2000035
#define GFARM_MSG_2000036	2000036
#define GFARM_MSG_2000037	2000037
#define GFARM_MSG_2000038	2000038
#define GFARM_MSG_2000039	2000039
#define GFARM_MSG_2000040	2000040
#define GFARM_MSG_2000041	2000041
#define GFARM_MSG_2000042	2000042
#define GFARM_MSG_2000043	2000043
#define GFARM_MSG_2000044	2000044
#define GFARM_MSG_2000045	2000045
#define GFARM_MSG_2000046	2000046
#define GFARM_MSG_2000047	2000047
#define GFARM_MSG_2000048	2000048
#define GFARM_MSG_2000049	2000049
#define GFARM_MSG_2000050	2000050
#define GFARM_MSG_2000051	2000051
#define GFARM_MSG_2000052	2000052
#define GFARM_MSG_2000053	2000053
#define GFARM_MSG_2000054	2000054
#define GFARM_MSG_2000055	2000055
#define GFARM_MSG_2000056	2000056
#define GFARM_MSG_2000057	2000057
